/* SQLEditor (SQLite)*/
DROP TABLE IF EXISTS RELATED;;
DROP TABLE IF EXISTS ROLES;;
DROP TABLE IF EXISTS CONTENT;;
DROP TABLE IF EXISTS IMAGEFILES;;
DROP TABLE IF EXISTS TYPES;;
DROP TABLE IF EXISTS OWNERS;;
DROP TABLE IF EXISTS EVENTS;;

CREATE TABLE EVENTS
(
id VARCHAR PRIMARY KEY UNIQUE,
isParent BOOLEAN,
"path" VARCHAR,
string VARCHAR,
argument VARCHAR,
image VARCHAR,
style VARCHAR,
workflow VARCHAR
);;

CREATE TABLE OWNERS
(
id VARCHAR PRIMARY KEY  UNIQUE,
objectClass VARCHAR,
"release" INTEGER,
bundleId VARCHAR,
identifier VARCHAR,
name VARCHAR,
info VARCHAR,
location VARCHAR,
logoId VARCHAR,
startDate DATE,
endDate DATE,
fileId VARCHAR
);;

CREATE TABLE IMAGEFILES
(
id VARCHAR,
fileId VARCHAR,
device INTEGER,
offline BOOLEAN,
ownerId VARCHAR,
PRIMARY KEY (id,fileId)
);;

CREATE TABLE RELATED
(
objectId VARCHAR,
relatedId VARCHAR,
ordering INTEGER,
inverseOrdering INTEGER,
PRIMARY KEY (objectId,relatedId)
);;

CREATE TABLE TYPES
(
id VARCHAR PRIMARY KEY  UNIQUE,
ownerId VARCHAR,
singular VARCHAR,
plural VARCHAR,
reverse VARCHAR,
sections VARCHAR
);;

CREATE TABLE CONTENT
(
id VARCHAR PRIMARY KEY  UNIQUE,
objectClass VARCHAR,
ownerId VARCHAR,
typeId VARCHAR,
name VARCHAR,
subNameList VARCHAR,
info VARCHAR,
subNameDetail VARCHAR,
parentId VARCHAR,
imageId VARCHAR,
timezone VARCHAR,
start DATETIME,
"end" DATETIME,
orderingName VARCHAR,
positionX DOUBLE,
positionY DOUBLE,
exhibitorId VARCHAR,
visible BOOLEAN,
offline BOOLEAN,
mimeType VARCHAR,
contentLocation VARCHAR,
fileId VARCHAR,
params VARCHAR
);;

CREATE TABLE ROLES
(
programId VARCHAR,
actorId VARCHAR,
typeId VARCHAR,
ordering INTEGER,
inverseOrdering INTEGER,
PRIMARY KEY (programId,actorId,typeId)
);;

CREATE TABLE PAGES
(
id VARCHAR PRIMARY KEY  UNIQUE,
ownerId VARCHAR,
name VARCHAR,
kind VARCHAR,
params VARCHAR
);;

CREATE INDEX IMAGEFILES_ownerId_idx ON IMAGEFILES(ownerId COLLATE BINARY ASC);;

CREATE UNIQUE INDEX RELATED_idx ON RELATED (objectId,relatedId COLLATE BINARY ASC);;

CREATE INDEX RELATED_objectId_idx ON RELATED(objectId COLLATE BINARY ASC);;

CREATE INDEX RELATED_relatedId_idx ON RELATED(relatedId COLLATE BINARY ASC);;

CREATE INDEX TYPES_ownerId_idx ON TYPES(ownerId COLLATE BINARY ASC);;

CREATE INDEX CONTENT_idx ON CONTENT (ownerId,typeId,parentId,imageId,fileId COLLATE BINARY ASC);;

CREATE INDEX CONTENT_objectClass_idx ON CONTENT(objectClass COLLATE BINARY ASC);;

CREATE INDEX CONTENT_ownerId_idx ON CONTENT(ownerId COLLATE BINARY ASC);;

CREATE INDEX CONTENT_typeId_idx ON CONTENT(typeId COLLATE BINARY ASC);;

CREATE INDEX CONTENT_parentId_idx ON CONTENT(parentId COLLATE BINARY ASC);;


CREATE VIRTUAL TABLE ContentFtsIndex USING fts4(rowid, content);;

CREATE TRIGGER fts_index_insert AFTER INSERT ON Content
FOR EACH ROW BEGIN
    INSERT INTO ContentFtsIndex (rowid, content) VALUES (last_insert_rowid(), (COALESCE(NEW.name, '') || ' ' || COALESCE(NEW.info, '') || ' ' || COALESCE(NEW.subNameList, '') || ' ' || COALESCE(NEW.subNameDetail, '') ));
END;;

CREATE TRIGGER fts_index_update AFTER Update ON Content
FOR EACH ROW BEGIN
    UPDATE ContentFtsIndex SET content = (COALESCE(NEW.name, '') || ' ' || COALESCE(NEW.info, '') || ' ' || COALESCE(NEW.subNameList, '') || ' ' || COALESCE(NEW.subNameDetail, '') ) WHERE rowid = OLD.rowid;
END;;

CREATE TRIGGER fts_index_delete AFTER DELETE ON Content
FOR EACH ROW BEGIN
    DELETE FROM ContentFtsIndex WHERE rowid = OLD.rowid;
END;;

